export interface Ref {
	__ref: string;
}

export interface BookContributorEdge {
	__typename: "BookContributorEdge";
	node: Ref;
	role: string;
}

export interface BookSeries {
	__typename: "BookSeries";
	userPosition: string;
	series: Ref;
}

export interface Genre {
	__typename: "Genre";
	name: string;
	webUrl: string;
}

export interface BookGenre {
	__typename: "BookGenre";
	genre: Genre;
}

export interface Language {
	__typename: "Language";
	name: string;
}

export interface BookDetails {
	__typename: "BookDetails";
	asin: string;
	format: string;
	numPages: number;
	publicationTime: number;
	publisher: string;
	isbn: string;
	isbn13: string;
	language: Language;
}

export interface Book {
	__typename: "Book";
	id: string;
	legacyId: number;
	webUrl: string;
	title: string;
	titleComplete: string;
	description: string;
	primaryContributorEdge: BookContributorEdge;
	secondaryContributorEdges: BookContributorEdge[];
	imageUrl: string;
	bookSeries: BookSeries[];
	bookGenres: BookGenre[];
	details: BookDetails;
	work: Ref;
}

export interface ContributorWorksConnection {
	__typename: "ContributorWorksConnection";
	totalCount: number;
}

export interface ContributorFollowersConnection {
	__typename: "ContributorFollowersConnection";
	totalCount: number;
}

export interface Contributor {
	__typename: "Contributor";
	id: string;
	legacyId: number;
	name: string;
	description: string;
	isGrAuthor: boolean;
	works: ContributorWorksConnection;
	profileImageUrl: string;
	webUrl: string;
	followers: ContributorFollowersConnection;
}

export interface Series {
	__typename: "Series";
	id: string;
	title: string;
	webUrl: string;
}

export interface Work {
	__typename: "Work";
	id: string;
	legacyId: number;
	bestBook: Ref;
	// ...
}

export interface Query {
	__typename: "Query";
	[key: string]: any;
}

export interface NextData {
	props: {
		pageProps: {
			apolloState: {
				ROOT_QUERY: Query;
				[key: string]: any;
			};
			params: Record<string, string>;
			query: Record<string, string>;
			jwtToken: string;
			dataSource: string;
		};
	};
}

export interface SearchResult {
	legacyId: number;
	title: string;
	authors: string[];
	avgRating: number;
	ratingCount: number;
	publicationYear: number;
	editionCount: number;
	coverImageUrl: string;
}
