import { SearchResult } from "@data-sources/goodreads/types";
import { App, Notice, SuggestModal } from "obsidian";

export class GoodreadsSearchSuggestModal extends SuggestModal<SearchResult> {
	constructor(
		app: App,
		private readonly results: SearchResult[],
		private readonly onChoose: (error: any, results: SearchResult[]) => void
	) {
		super(app);
	}

	getSuggestions(query: string): SearchResult[] | Promise<SearchResult[]> {
		return this.results;
	}

	renderSuggestion(value: SearchResult, el: HTMLElement): void {
		el.addClass("obt-goodreads-search-suggest__item");
		el.createEl("img", {
			cls: "obt-goodreads-search-suggest__cover",
			attr: {
				src: value.coverImageUrl,
				alt: `Cover of ${value.title}`,
			},
		});

		el.createDiv(
			{ cls: "obt-goodreads-search-suggest__info" },
			(infoEl) => {
				infoEl.createEl("h2", {
					text: value.title,
					cls: "obt-goodreads-search-suggest__title",
				});

				let subtitle = value.authors.join(", ");
				if (value.publicationYear > 0) {
					subtitle += ` (${value.publicationYear})`;
				}

				infoEl.createEl("h3", {
					text: subtitle,
					cls: "obt-goodreads-search-suggest__subtitle",
				});
			}
		);
	}

	onChooseSuggestion(
		item: SearchResult,
		evt: MouseEvent | KeyboardEvent
	): void {
		this.onChoose(null, [item]);
	}

	static async createAndOpen(
		app: App,
		results: SearchResult[]
	): Promise<SearchResult | undefined> {
		return new Promise((resolve, reject) => {
			const modal = new GoodreadsSearchSuggestModal(
				app,
				results,
				(error, results) => {
					if (error) {
						new Notice(`Error: ${error.message}`);
						reject(error);
					} else {
						resolve(results[0]);
					}
				}
			);
			modal.open();
		});
	}
}
